@@ -1,4 +1,5 @@
-from lcapy import *
+from lcapy import (symbol, nexpr, n, k, rect, sinc, sign, sin, cos, exp,
+                   dt, j, pi, delta, H)
 
 alpha = symbol('alpha')
 m = symbol('m', integer=True)
@@ -18,4 +19,5 @@ sigs2 = [n, n**2, 1 / n, rect(n), sinc(n), alpha**-abs(n), sign(n),
          cos(w0 * n * dt), sin(w0 * n * dt), exp(j * w0 * n * dt)]
 
 for sig in sigs:
-    print(':math:`%s \\longleftrightarrow %s`\n' % (sig.latex(), sig(k, N=N).simplify().latex()))
+    print(':math:`%s \\longleftrightarrow %s`\n' %
+          (sig.latex(), sig(k, N=N).simplify().latex()))
