@@ -69,16 +69,15 @@ class PhasorExpression(Expr):
     def var(self):
         """Return underlying variable as sympy expression."""
 
-        # TODO, think this through...
-        var = self.omega
-        if hasattr(var, 'expr'):
-            raise ValueError('FIXME, omega is Lcapy symbol')
+        from .sym import fsym, omegasym, pi
 
-        # Handle things like 2 * pi * f
-        if isinstance(var, symExpr) and var.is_Mul:
-            return None
+        if self.omega == omegasym:
+            return omegasym
 
-        return var
+        if self.omega == 2 * pi * fsym:
+            return fsym
+
+        return None
 
     def phasor(self, **assumptions):
         """Convert to phasor representation."""
@@ -93,40 +92,13 @@ class PhasorExpression(Expr):
 
         return abs(self) * sqrt(2) / 2
 
-    def plot(self, wvector=None, **kwargs):
-        """Plot polar diagram for a time-domain phasor or frequency response
-        for a frequency-domain phasor.  For the latter, wvector
-        specifies the angular frequencies.  If it is a tuple, it sets
-        the angular frequency limits."""
+    def _compatible_phasors(self, x):
 
-        from .plot import plot_phasor, plot_angular_frequency
+        if self.domain != x.domain:
+            return False
 
-        if self.is_phasor_time_domain:
-            return plot_phasor(self, **kwargs)
-
-        if self.omega.is_constant():
-            raise ValueError('Cannot plot at single frequency')
-
-        return plot_angular_frequency(self, wvector, **kwargs)
-
-    def bode_plot(self, fvector=None, unwrap=True, **kwargs):
-        """Plot frequency response for a frequency-domain phasor as a Bode
-        plot (but without the straight line approximations).  fvector
-        specifies the frequencies.  If it is a tuple (m1, m2), it sets the
-        frequency limits as (10**m1, 10**m2).
-
-        `unwrap` controls phase unwrapping (default True).
-        """
-
-        from .plot import plot_bode
-
-        if not self.is_phasor_frequency_domain:
-            raise ValueError('Not frequency domain phasor: use plot()')
-
-        result = self.fourier()
-        return plot_bode(result, fvector, unwrap=unwrap, **kwargs)
-
-    def _mul_compatible(self, x):
+        if False and self.is_phasor_time_domain ^ x.is_phasor_time_domain:
+            return False
 
         if not hasattr(x, 'omega'):
             return True
@@ -137,6 +109,37 @@ class PhasorExpression(Expr):
         raise ValueError('Incompatible phasor angular frequencies %s and %s' %
                          (self.omega, x.omega))
 
+    def _add_compatible_domains(self, x):
+
+        return self._compatible_phasors(x)
+
+    def _div_compatible_domains(self, x):
+
+        if (self.is_constant_domain or x.is_constant_domain):
+            return True
+
+        return self._compatible_phasors(x)
+
+    def _mul_compatible_domains(self, x):
+
+        from .sym import pi
+
+        if (self.is_constant_domain or x.is_constant_domain):
+            return True
+
+        if self._compatible_phasors(x):
+            return True
+
+        # Allow phasor(x) * omega, etc.
+        if (self.is_phasor_domain and x.is_angular_fourier_domain and
+                self.omega == x.var):
+            return True
+        if (self.is_phasor_domain and x.is_fourier_domain and
+                self.omega == 2 * pi * x.var):
+            return True
+
+        return False
+
     def subs(self, *args, safe=False, **kwargs):
         """Substitute variables in expression, see sympy.subs for usage."""
 
@@ -257,6 +260,13 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
 
         return self.time().fourier()
 
+    def plot(self, **kwargs):
+        """Plot polar diagram."""
+
+        from .plot import plot_phasor
+
+        return plot_phasor(self, **kwargs)
+
 
 class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
     """This represents the ratio of two-phasors; for example
@@ -307,7 +317,7 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
 
         # Substitute jw for s
         result = expr.laplace(**ass)
-        result2 = result.expr.replace(ssym, j * omegasym)
+        result2 = result.expr.replace(ssym, j * omega)
 
         quantity = expr.quantity
         if quantity == 'undefined':
@@ -318,6 +328,33 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
         ret = cls(result2, omega=omega, **ass)
         return ret
 
+    @property
+    def domain_label(self):
+
+        from .sym import fsym
+
+        # TODO, remove this say by having PhasorFrequencyDomainExpression
+        # and PhasorAngularFrequencyDomainExpression classes.
+
+        if self.var == fsym:
+            return 'Frequency'
+        else:
+            return 'Angular frequency'
+
+    @property
+    def domain_units(self):
+
+        from .sym import fsym
+        from .units import u as uu
+
+        # TODO, remove this say by having PhasorFrequencyDomainExpression
+        # and PhasorAngularFrequencyDomainExpression classes.
+
+        if self.var == fsym:
+            return uu.Hz
+        else:
+            return uu.rad / uu.s
+
     def time(self, **assumptions):
         """Convert to time domain representation."""
 
@@ -353,6 +390,41 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
     def as_expr(self):
         return PhasorFrequencyDomainExpression(self)
 
+    def plot(self, fvector=None, **kwargs):
+        """Plot frequency response.
+
+        If the dependent variable is omega, fvector specifies the angular
+        frequencies.  If it is a tuple, it sets the angular frequency
+        limits.
+
+        If the dependent variable is f, fvector specifies the linear
+        frequencies.  If it is a tuple, it sets the linear frequency
+        limits."""
+
+        from .plot import plot_angular_frequency, plot_frequency
+        from .sym import fsym
+
+        if self.omega.is_constant():
+            raise ValueError('Cannot plot at single frequency')
+
+        if self.var == fsym:
+            return plot_frequency(self, fvector, **kwargs)
+
+        return plot_angular_frequency(self, fvector, **kwargs)
+
+    def bode_plot(self, fvector=None, unwrap=True, **kwargs):
+        """Plot frequency response for a frequency-domain phasor as a Bode
+        plot (but without the straight line approximations).  fvector
+        specifies the frequencies.  If it is a tuple (m1, m2), it sets the
+        frequency limits as (10**m1, 10**m2).
+
+        `unwrap` controls phase unwrapping (default True).
+        """
+
+        from .plot import plot_bode
+
+        return plot_bode(self, fvector, unwrap=unwrap, **kwargs)
+
 
 def phasor(arg, omega=None, **assumptions):
     """Create phasor.
@@ -373,13 +445,9 @@ def phasor(arg, omega=None, **assumptions):
     if arg.is_time_domain:
         # Expecting AC signal.
         return PhasorTimeDomainExpression.from_time(arg, omega=omega, **assumptions)
-    elif arg.is_unchanging:
+    else:
         # Expecting phasor (complex amplitude)
         return PhasorTimeDomainExpression(arg, omega=omega, **assumptions)
-    else:
-        # Is this sensible?  It is probably better to have
-        # a phasorratio function.  TODO add deprecation warning.
-        return PhasorFrequencyDomainExpression(arg, omega=omega, **assumptions)
 
 
 expressionclasses.register('phasor', PhasorTimeDomainExpression,
