@@ -8,8 +8,8 @@ Copyright 2014--2022 Michael Hayes, UCECE
 from __future__ import division
 from .domains import LaplaceDomain
 from .inverse_laplace import inverse_laplace_transform
-from .state import state
-from .sym import ssym, tsym, j, pi, sympify
+from .state import state, validate
+from .sym import ssym, tsym, fsym, omegasym, j, pi, sympify
 from .ratfun import _zp2tf, _pr2tf, Ratfun
 from .expr import Expr, symbol, expr, ExprDict, ExprList, exprcontainer, expr_make
 from .differentialequation import DifferentialEquation
@@ -34,10 +34,17 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         super(LaplaceDomainExpression, self).__init__(val, **assumptions)
 
         expr = self.expr
-        # Be more specific
-        if check and expr.has(tsym) and not expr.has(Derivative) and not expr.has(Integral):
-            raise ValueError(
-                's-domain expression %s cannot depend on t' % expr)
+
+        if check and not expr.has(ssym):
+            if expr.has(fsym):
+                validate(state.f_in_s,
+                         's-domain expression %s depends on f' % expr)
+            if expr.has(tsym):
+                validate(state.t_in_s,
+                         's-domain expression % s depends on t' % expr)
+            if expr.has(omegasym):
+                validate(state.w_in_s,
+                         's-domain expression %s depends on omega' % expr)
 
     def as_expr(self):
         return LaplaceDomainExpression(self)
@@ -164,12 +171,14 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         """Convert to Fourier domain."""
         from .symbols import f, jw, pi
 
-        if self.is_causal or assumptions.get('causal', False):
-            # Note, this does not apply for 1 / s.
+        # Require f = 0 in the region of convergence.  This is
+        # achieved if the expression is the Laplace transform of a
+        # stable impulse response.
+        if ((self.is_causal or assumptions.get('causal', False))
+                and self.is_stable):
             tmp = self.subs(jw)
-            if tmp.real != 0:
-                return self.change(tmp.subs(2 * pi * f, safe=True),
-                                   domain='fourier', **assumptions)
+            return self.change(tmp.subs(2 * pi * f, safe=True),
+                               domain='fourier', **assumptions)
 
         result = self.time(**assumptions).fourier(**assumptions)
         return result
@@ -178,12 +187,11 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         """Convert to angular Fourier domain."""
         from .symbols import jw
 
-        if self.is_causal:
-            # Note, this does not apply for 1 / s.
+        if ((self.is_causal or assumptions.get('causal', False))
+                and self.is_stable):
             tmp = self(jw)
-            if tmp.real != 0:
-                return self.change(tmp, domain='angular fourier',
-                                   **assumptions)
+            return self.change(tmp, domain='angular fourier',
+                               **assumptions)
 
         result = self.time(**assumptions).angular_fourier(**assumptions)
         return result
@@ -192,12 +200,11 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         """Convert to normalized angular Fourier domain."""
         from .symbols import jw, Omega
 
-        if self.is_causal:
-            # Note, this does not apply for 1 / s.
+        if ((self.is_causal or assumptions.get('causal', False))
+                and self.is_stable):
             tmp = self(j * Omega / dt)
-            if tmp.real != 0:
-                return self.change(tmp, domain='norm angular fourier',
-                                   **assumptions)
+            return self.change(tmp, domain='norm angular fourier',
+                               **assumptions)
 
         result = self.time(**assumptions).norm_angular_fourier(**assumptions)
         return result
@@ -206,12 +213,11 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         """Convert to normalized Fourier domain."""
         from .symbols import jw, F
 
-        if self.is_causal:
-            # Note, this does not apply for 1 / s.
+        if ((self.is_causal or assumptions.get('causal', False))
+                and self.is_stable):
             tmp = self(j * F / dt)
-            if tmp.real != 0:
-                return self.change(tmp, domain='norm fourier',
-                                   **assumptions)
+            return self.change(tmp, domain='norm fourier',
+                               **assumptions)
 
         result = self.time(**assumptions).norm_fourier(**assumptions)
         return result
@@ -242,28 +248,46 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         H = self.__class__(self / self.var, **self.assumptions)
         return H.transient_response(tvector)
 
-    def angular_frequency_response(self, wvector=None):
+    def angular_frequency_response(self, wvector=None, strict=False):
         """Convert to angular frequency domain and evaluate response if
         angular frequency vector specified.
 
         """
         from .symbols import omega
 
-        X = self.subs(j * omega)
+        return self.frequency_response(wvector, var=omega, strict=strict)
 
-        if wvector is None:
-            return X
-
-        return X.evaluate(wvector)
-
-    def frequency_response(self, fvector=None):
+    def frequency_response(self, fvector=None, var=None, strict=False):
         """Convert to frequency domain and evaluate response if frequency
         vector specified.
 
-        """
-        from .symbols import f
+        If `var` is None or `f` use linear frequency otherwise if
+        `var` is `omega` use angular frequency.
 
-        X = self.subs(j * 2 * pi * f)
+        If `strict` is True, evaluate frequency response via Fourier
+        transform.
+
+        """
+        from .symbols import f, omega
+
+        # Perhaps if strict is False warn if the expression is
+        # not a Laplace transform of a stable impulse response?
+
+        if var is None:
+            var = f
+
+        if id(var) == id(f):
+            if strict:
+                X = self(f)
+            else:
+                X = self.subs(j * 2 * pi * f)
+        elif id(var) == id(omega):
+            if strict:
+                X = self(omega)
+            else:
+                X = self.subs(j * omega)
+        else:
+            raise ValueError('var not f or omega: ' % var)
 
         if fvector is None:
             return X
@@ -513,24 +537,31 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
 
         return self.plot(**kwargs)
 
-    def bode_plot(self, fvector=None, unwrap=True, **kwargs):
+    def bode_plot(self, fvector=None, unwrap=True, var=None, strict=False,
+                  **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Bode
-        plot (but without the straight line approximations).  fvector
-        specifies the frequencies.  If it is a tuple (f1, f2), it sets
-        the frequency limits.   Since a logarithmic frequency scale is used,
-        f1 must be greater than 0.
+        plot (but without the straight line approximations).
+
+        If `var` is None or `f`, `fvector` specifies the (linear)
+        frequencies (in hertz) otherwise if `var` is `omega`,
+        `fvector` specifies the angular frequencies (in radians).
+
+         If `fvector` is a tuple (f1, f2), it sets the frequency
+        limits.  Since a logarithmic frequency scale is used, f1 must
+        be greater than 0.
 
         `unwrap` controls phase unwrapping (default True).
 
         This method makes the assumption that the expression is causal.
         Note, the Bode plot does not exist for marginally stable and unstable
         systems since `jw` is outside the region of convergence.
+
         """
 
-        return self.fourier(causal=True).bode_plot(fvector, unwrap=unwrap,
-                                                   **kwargs)
+        H = self.frequency_response(var=var, strict=strict)
+        return H.bode_plot(fvector, unwrap=unwrap, **kwargs)
 
-    def nyquist_plot(self, fvector=None, **kwargs):
+    def nyquist_plot(self, fvector=None, var=None, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Nyquist
         plot (imaginary part versus real part).  fvector specifies the
         frequencies.  If it is a tuple (f1, f2), it sets the frequency
@@ -543,9 +574,10 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         This method makes the assumption that the expression is causal.
         """
 
-        return self.fourier(causal=True).nyquist_plot(fvector, **kwargs)
+        H = self.frequency_response(var=var)
+        return H.nyquist_plot(fvector, **kwargs)
 
-    def nichols_plot(self, fvector=None, **kwargs):
+    def nichols_plot(self, fvector=None, var=None, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Nichols
         plot (dB versus phase).  fvector specifies the frequencies.
         If it is a tuple (f1, f2), it sets the frequency limits.
@@ -556,7 +588,8 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
 
         """
 
-        return self.fourier(causal=True).nichols_plot(fvector, **kwargs)
+        H = self.frequency_response(var=var)
+        return H.nichols_plot(fvector, **kwargs)
 
     def generalized_bilinear_transform(self, alpha=0.5):
 
