@@ -13,6 +13,7 @@ from .config import canonical_units, printing_order
 from .printing_config import PrintingConfig
 from .symbolregistry import SymbolRegistry
 from copy import copy
+from warnings import warn
 
 
 class State(object):
@@ -51,6 +52,36 @@ class State(object):
 
         self.zero_initial_conditions = False
 
+        # The following can either be `allow`, `warn`, or `error`.
+        # They are used in expr.c:__mul__ to validate multiplications.
+        self.s_times_t = 'warn'
+        self.t_times_s = 'warn'
+        self.f_times_t = 'warn'
+        self.t_times_f = 'warn'
+        self.w_times_t = 'warn'
+        self.t_times_w = 'warn'
+
+        # The following can either be `allow`, `warn`, or `error`.
+        # They are used in the expression class constructors.
+        self.f_in_t = 'warn'
+        self.s_in_t = 'warn'
+        self.w_in_t = 'warn'
+
+        self.f_in_s = 'warn'
+        self.t_in_s = 'warn'
+        self.w_in_s = 'warn'
+
+        self.s_in_f = 'warn'
+        self.t_in_f = 'warn'
+        self.w_in_f = 'warn'
+
+        self.f_in_w = 'warn'
+        self.s_in_w = 'warn'
+        self.t_in_w = 'warn'
+
+        self.pdb_on_warn = False
+        self.error_on_warn = False
+
     def new_context(self):
 
         context = Context()
@@ -86,4 +117,22 @@ class State(object):
         self.printing.abbreviate_units = val
 
 
+def validate(value, message):
+
+    if value == 'allow':
+        pass
+    elif value == 'warn':
+        if state.pdb_on_warn:
+            import pdb
+            pdb.set_trace()
+        if state.error_on_warn:
+            raise ValueError(message)
+        else:
+            warn(message)
+    elif value == 'error':
+        raise ValueError(message)
+    else:
+        raise RuntimeError('Unexpected option ' + value)
+
+
 state = State()
