@@ -5,10 +5,12 @@ Copyright 2021--2022 Michael Hayes, UCECE
 
 """
 
+from .sexpr import LaplaceDomainExpression
 from .cache import cached_property
 from .matrix import Matrix
 from .smatrix import LaplaceDomainMatrix
 from .tmatrix import TimeDomainMatrix
+from .nmatrix import DiscreteTimeDomainMatrix
 from .statespacebase import StateSpaceBase
 from .texpr import t, texpr
 from .expr import expr
@@ -62,17 +64,17 @@ class StateSpace(StateSpaceBase):
     @property
     def U(self):
         """Laplace transform of input vector."""
-        return LaplaceDomainMatrix(self.u.laplace())
+        return LaplaceDomainMatrix(self.u.LT())
 
     @property
     def X(self):
         """Laplace transform of state-variable vector."""
-        return LaplaceDomainMatrix(self.x.laplace())
+        return LaplaceDomainMatrix(self.x.LT())
 
     @property
     def Y(self):
         """Laplace transform of output vector."""
-        return LaplaceDomainMatrix(self.y.laplace())
+        return LaplaceDomainMatrix(self.y.LT())
 
     @cached_property
     def H(self):
@@ -249,7 +251,10 @@ class StateSpace(StateSpaceBase):
 
         # FIXME for u, y, x, x0.
         return DTStateSpace(Ad, Bd, Cd, Dd,
-                            self._u, self._y, self._x, self._x0)
+                            DiscreteTimeDomainMatrix(self._u),
+                            DiscreteTimeDomainMatrix(self._y),
+                            DiscreteTimeDomainMatrix(self._x),
+                            DiscreteTimeDomainMatrix(self._x0))
 
     def discretize(self, method='bilinear', alpha=0.5):
         """Convert to a discrete-time state space approximation.
@@ -275,6 +280,3 @@ class StateSpace(StateSpaceBase):
         from .statespacemaker import StateSpaceMaker
 
         return StateSpaceMaker.from_circuit(cct, node_voltages, branch_currents)
-
-
-from .sexpr import LaplaceDomainExpression
