@@ -17,14 +17,17 @@ from .kexpr import k
 from .zexpr import z
 
 # Import common SymPy symbols.
-from .sym import pi, j, oo, inf, one, omega0sym
+from .sym import pi, j, oo, inf, one, omega0sym, f0sym
 
 # Perhaps have class for domainconstants such as omega0, t0, f0, etc.
 omega0 = omega0sym
+f0 = f0sym
 
 jomega = j * omega
 jw = jomega
 
+j2pif = j * 2 * pi * f
+
 jomega0 = j * omega0
 jw0 = jomega0
 
