@@ -811,3 +811,41 @@ class LcapyTester(unittest.TestCase):
         b = a.expand()
 
         self.assertEqual(str(b), 'E__E1 3 0 1 2 E1 0', 'opamp expand')
+
+    def test_R_simplify(self):
+
+        a = Circuit("""
+        R1 1 2 10
+        R2 2 3 5
+        R3 3 4 15""")
+
+        self.assertEqual(a.simplify().Rt1.R, 30, 'series R')
+        self.assertEqual(a.simplify_series().Rt1.R, 30, 'series R')
+        self.assertEqual(a.simplify_series(
+            ignore=['R3']).Rt1.R, 15, 'series R')
+
+        self.assertEqual(len(a.simplify().remove_dangling_wires().elements),
+                         1, 'dangling wires')
+
+        b = Circuit("""
+        R1 1 2 20
+        R2 1 2 60
+        R3 1 2 15""")
+
+        self.assertEqual(b.simplify().Rt1.R, 7.5, 'parallel R')
+        self.assertEqual(b.simplify_parallel().Rt1.R, 7.5, 'parallel R')
+        self.assertEqual(b.simplify_parallel(
+            ignore=['R1']).Rt1.R, 12, 'parallel R')
+        self.assertEqual(b.simplify_parallel(
+            select=['R2', 'R3']).Rt1.R, 12, 'parallel R')
+
+        c = Circuit("""
+        R1 1 2 20
+        R2 1 2 60
+        R3 3 4 15""")
+
+        self.assertEqual(c.simplify().Rt1.R, 15,
+                         'parallel R with disconnected')
+
+        self.assertEqual(len(c.remove_disconnected().elements),
+                         2, 'disconnected')
