@@ -9,8 +9,8 @@ from __future__ import division
 from .domains import TimeDomain
 from .expr import Expr, expr_make
 from .functions import exp
-from .state import state
-from .sym import fsym, ssym, tsym, j, oo
+from .state import state, validate
+from .sym import fsym, omegasym, ssym, tsym, j, oo
 from .laplace import laplace_transform
 from .fourier import fourier_transform
 from .units import u as uu
@@ -32,13 +32,17 @@ class TimeDomainExpression(TimeDomain, Expr):
         super(TimeDomainExpression, self).__init__(val, **assumptions)
 
         expr = self.expr
-        # Should be more specific...
-        if check and expr.has(ssym) and not expr.has(Integral) and not expr.has(Derivative):
-            raise ValueError(
-                't-domain expression %s cannot depend on s' % expr)
-        if check and expr.has(fsym) and not expr.has(Integral):
-            raise ValueError(
-                't-domain expression %s cannot depend on f' % expr)
+
+        if check and not expr.has(tsym):
+            if expr.has(fsym):
+                validate(state.f_in_t,
+                         't-domain expression %s depends on f' % expr)
+            if expr.has(ssym):
+                validate(state.s_in_t,
+                         't-domain expression %s depends on s' % expr)
+            if expr.has(omegasym):
+                validate(state.w_in_t,
+                         't-domain expression %s depends on omega' % expr)
 
     def _mul_compatible_domains(self, x):
 
@@ -79,6 +83,10 @@ class TimeDomainExpression(TimeDomain, Expr):
         if zero_initial_conditions is None:
             zero_initial_conditions = state.zero_initial_conditions
 
+        if self.has(ssym):
+            raise ValueError(
+                'Time-domain expression has s.  Substitute with another symbol, say p')
+
         assumptions = self.assumptions.merge_and_infer(self, **assumptions)
         result = laplace_transform(
             self.expr, self.var, ssym, evaluate=evaluate,
@@ -117,6 +125,10 @@ class TimeDomainExpression(TimeDomain, Expr):
             raise ValueError(
                 'FT requires var to be f, F, omega, or Omega`, not %s' % var)
 
+        if self.has(var):
+            raise ValueError(
+                'Time-domain expression has %s.  Substitute with another symbol, say %s0' % (var, var))
+
         assumptions = self.assumptions.merge_and_infer(self, **assumptions)
         result = fourier_transform(
             self.expr, self.var, fsym, evaluate=evaluate)
@@ -144,10 +156,6 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         from .symbols import omega
 
-        if self.has(omega):
-            raise ValueError(
-                'Time-domain expression has omega.  Substitute with another symbol, say omega0')
-
         return self.FT(omega, evaluate, **assumptions)
 
     def norm_angular_fourier(self, evaluate=True, **assumptions):
