@@ -3,6 +3,7 @@
 Copyright 2021--2022 Michael Hayes, UCECE
 """
 
+from warnings import warn
 import sympy as sym
 
 
@@ -178,6 +179,7 @@ def factor_expr(expr, factor):
 
 
 def separate_dirac_delta(expr):
+    """Separate Dirac delta terms from expression."""
 
     terms = expr.as_ordered_terms()
     deltas = []
